==> featuretools-1.20.0.tar.gz: featuretools-1.20.0/featuretools/primitives/standard/transform/natural_language/__init__.py <==
from featuretools.primitives.standard.transform.natural_language.count_string import (
    CountString,
)
from featuretools.primitives.standard.transform.natural_language.mean_characters_per_word import (
    MeanCharactersPerWord,
)
from featuretools.primitives.standard.transform.natural_language.median_word_length import (
    MedianWordLength,
)
from featuretools.primitives.standard.transform.natural_language.num_characters import (
    NumCharacters,
)
from featuretools.primitives.standard.transform.natural_language.num_unique_separators import (
    NumUniqueSeparators,
)
from featuretools.primitives.standard.transform.natural_language.num_words import (
    NumWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_common_words import (
    NumberOfCommonWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_hashtags import (
    NumberOfHashtags,
)
from featuretools.primitives.standard.transform.natural_language.number_of_mentions import (
    NumberOfMentions,
)
from featuretools.primitives.standard.transform.natural_language.number_of_unique_words import (
    NumberOfUniqueWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_words_in_quotes import (
    NumberOfWordsInQuotes,
)
from featuretools.primitives.standard.transform.natural_language.punctuation_count import (
    PunctuationCount,
)
from featuretools.primitives.standard.transform.natural_language.title_word_count import (
    TitleWordCount,
)
from featuretools.primitives.standard.transform.natural_language.total_word_length import (
    TotalWordLength,
)
from featuretools.primitives.standard.transform.natural_language.upper_case_count import (
    UpperCaseCount,
)
from featuretools.primitives.standard.transform.natural_language.whitespace_count import (
    WhitespaceCount,
)

==> featuretools-1.23.0.tar.gz: featuretools-1.23.0/featuretools/primitives/standard/transform/natural_language/__init__.py <==
from featuretools.primitives.standard.transform.natural_language.count_string import (
    CountString,
)
from featuretools.primitives.standard.transform.natural_language.mean_characters_per_word import (
    MeanCharactersPerWord,
)
from featuretools.primitives.standard.transform.natural_language.median_word_length import (
    MedianWordLength,
)
from featuretools.primitives.standard.transform.natural_language.num_characters import (
    NumCharacters,
)
from featuretools.primitives.standard.transform.natural_language.num_unique_separators import (
    NumUniqueSeparators,
)
from featuretools.primitives.standard.transform.natural_language.num_words import (
    NumWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_common_words import (
    NumberOfCommonWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_hashtags import (
    NumberOfHashtags,
)
from featuretools.primitives.standard.transform.natural_language.number_of_mentions import (
    NumberOfMentions,
)
from featuretools.primitives.standard.transform.natural_language.number_of_unique_words import (
    NumberOfUniqueWords,
)
from featuretools.primitives.standard.transform.natural_language.number_of_words_in_quotes import (
    NumberOfWordsInQuotes,
)
from featuretools.primitives.standard.transform.natural_language.punctuation_count import (
    PunctuationCount,
)
from featuretools.primitives.standard.transform.natural_language.title_word_count import (
    TitleWordCount,
)
from featuretools.primitives.standard.transform.natural_language.total_word_length import (
    TotalWordLength,
)
from featuretools.primitives.standard.transform.natural_language.upper_case_count import (
    UpperCaseCount,
)
from featuretools.primitives.standard.transform.natural_language.upper_case_word_count import (
    UpperCaseWordCount,
)
from featuretools.primitives.standard.transform.natural_language.whitespace_count import (
    WhitespaceCount,
)
